# Changelog

## Version 0.0.2 (development)

- feat: Add NM_CONFIG_DIR env var

## Version 0.0.1 (development)

- feat: Initial inet-nm-check
- feat: Initial inet-nm-commission
- feat: Initial inet-nm-exec
- feat: Initial inet-nm-free
- feat: Initial inet-nm-tmux
- feat: Initial inet-nm-tty-from-uid
- feat: Initial inet-nm-update-commissioned
- feat: Initial inet-nm-update-from-os
